@@ -13,11 +13,10 @@ class HooksInstaller:
     CLAUDE_SETTINGS_FILE = CLAUDE_SETTINGS_DIR / "settings.json"
 
     # ALLOWED hook types - ONLY these can be installed
-    # Note: PermissionRequest is NOT a valid Claude Code hook event!
-    # Permission notifications are handled via PreToolUse:Bash
-    ALLOWED_HOOK_TYPES = frozenset({"Stop", "PreToolUse"})
+    # PermissionRequest IS a valid Claude Code hook event (fires only for permission dialogs)
+    ALLOWED_HOOK_TYPES = frozenset({"Stop", "PreToolUse", "PermissionRequest"})
 
-    # BLOCKED hook types - these MUST NEVER be installed
+    # BLOCKED hook types - these MUST NEVER be installed (cause spam)
     BLOCKED_SPAM_HOOKS = frozenset({
         "SessionStart",
         "SessionEnd",
@@ -28,12 +27,8 @@ class HooksInstaller:
     # Hook definitions for WatchCode
     # Event types supported by the Watch app:
     # - stop (task completed)
-    # - permission_request (tool needs approval) - via PreToolUse:Bash
+    # - permission_request (tool needs approval) - via PermissionRequest hook
     # - question (Claude asks user a question via AskUserQuestion)
-    #
-    # Note: "PermissionRequest" is NOT a valid Claude Code hook event!
-    # Claude Code hook events are: PreToolUse, PostToolUse, Stop, SubagentStop,
-    # SessionStart, SessionEnd, UserPromptSubmit, Notification, PreCompact
     WATCHCODE_HOOKS = {
         "Stop": [
             {
@@ -45,6 +40,17 @@ class HooksInstaller:
                 ]
             }
         ],
+        "PermissionRequest": [
+            {
+                # Send notification for permission dialogs (Bash, Write, Edit, etc.)
+                "hooks": [
+                    {
+                        "type": "command",
+                        "command": "python3 ~/.watchcode/hook_handler.py permission_request"
+                    }
+                ]
+            }
+        ],
         "PreToolUse": [
             {
                 # Send notification for AskUserQuestion tool (questions)
@@ -55,16 +61,6 @@ class HooksInstaller:
                         "command": "watchcode notify --event question --requires-action"
                     }
                 ]
-            },
-            {
-                # Send notification for Bash commands (permission requests)
-                "matcher": "Bash",
-                "hooks": [
-                    {
-                        "type": "command",
-                        "command": "watchcode notify --event permission_request --requires-action"
-                    }
-                ]
             }
         ]
     }
@@ -249,9 +245,8 @@ class HooksInstaller:
 
         return status
 
-    # Legacy spam hooks that should NEVER be installed
-    # PermissionRequest was added by mistake - it's not a valid Claude Code hook event
-    LEGACY_SPAM_HOOKS = {"SessionStart", "SessionEnd", "Notification", "PermissionRequest"}
+    # Legacy spam hooks that should be cleaned up
+    LEGACY_SPAM_HOOKS = {"SessionStart", "SessionEnd", "Notification"}
 
     def cleanup_legacy_hooks(self) -> Dict[str, Any]:
         """Remove legacy spam hooks that should never have been installed.
